@@ -1,5 +1,8 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/SysConfig/PriorityValidate.pm - all PriorityValidate functions
+# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# --
+# $Id: PriorityValidate.pm,v 1.1 2010-07-28 08:49:24 ub Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,10 +14,11 @@ package Kernel::System::SysConfig::PriorityValidate;
 use strict;
 use warnings;
 
-our @ObjectDependencies = (
-    'Kernel::System::Log',
-    'Kernel::System::Priority',
-);
+use Kernel::Config;
+use Kernel::System::Priority;
+
+use vars qw(@ISA $VERSION);
+$VERSION = qw($Revision: 1.1 $) [1];
 
 =head1 NAME
 
@@ -32,11 +36,47 @@ All functions for the PriorityValidate checks.
 
 =item new()
 
-create an object. Do not use it directly, instead use:
+create an object
 
-    use Kernel::System::ObjectManager;
-    local $Kernel::OM = Kernel::System::ObjectManager->new();
-    my $PriorityValidateObject = $Kernel::OM->Get('Kernel::System::SysConfig::PriorityValidate');
+    use Kernel::Config;
+    use Kernel::System::Encode;
+    use Kernel::System::Log;
+    use Kernel::System::DB;
+    use Kernel::System::Main;
+    use Kernel::System::Time;
+    use Kernel::System::SysConfig::PriorityValidate;
+
+    my $ConfigObject = Kernel::Config->new();
+    my $EncodeObject = Kernel::System::Encode->new(
+        ConfigObject => $ConfigObject,
+    );
+    my $LogObject = Kernel::System::Log->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+    );
+    my $MainObject = Kernel::System::Main->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+        LogObject    => $LogObject,
+    );
+    my $TimeObject = Kernel::System::Time->new(
+        ConfigObject => $ConfigObject,
+        LogObject    => $LogObject,
+    );
+    my $DBObject = Kernel::System::DB->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+        LogObject    => $LogObject,
+        MainObject   => $MainObject,
+    );
+    my $PriorityValidateObject = Kernel::System::SysConfig::PriorityValidate->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+        LogObject    => $LogObject,
+        DBObject     => $DBObject,
+        TimeObject   => $TimeObject,
+        MainObject   => $MainObject,
+    );
 
 =cut
 
@@ -47,6 +87,14 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
+    # check needed objects
+    for my $Object (qw(DBObject ConfigObject EncodeObject LogObject MainObject TimeObject)) {
+        $Self->{$Object} = $Param{$Object} || die "Got no $Object!";
+    }
+
+    # create additional objects
+    $Self->{PriorityObject} = Kernel::System::Priority->new( %{$Self} );
+
     # set the debug flag
     $Self->{Debug} = $Param{Debug} || 0;
 
@@ -68,7 +116,7 @@ sub Validate {
 
     # check needed stuff
     if ( !$Param{Data} ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $Self->{LogObject}->Log(
             Priority => 'error',
             Message  => "Need Data!",
         );
@@ -81,7 +129,7 @@ sub Validate {
         # get the reference type
         my $RefType = ref $Param{Data};
 
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $Self->{LogObject}->Log(
             Priority => 'error',
             Message  => "Data must be a scalar, but it is a $RefType!",
         );
@@ -89,7 +137,7 @@ sub Validate {
     }
 
     # get list of all valid priorities
-    my %Priorities = $Kernel::OM->Get('Kernel::System::Priority')->PriorityList(
+    my %Priorities = $Self->{PriorityObject}->PriorityList(
         Valid => 1,
     );
 
@@ -115,7 +163,7 @@ sub GetAutoCorrectValue {
     my ( $Self, %Param ) = @_;
 
     # get list of all valid priorities
-    my %Priorities = $Kernel::OM->Get('Kernel::System::Priority')->PriorityList(
+    my %Priorities = $Self->{PriorityObject}->PriorityList(
         Valid => 1,
     );
 
@@ -160,3 +208,9 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
+
+=head1 VERSION
+
+$Revision: 1.1 $ $Date: 2010-07-28 08:49:24 $
+
+=cut
