@@ -1,6 +1,9 @@
-#!/usr/bin/perl
+#!/usr/bin/perl -w
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# bin/otrs.AddUser2Role.pl - Assign users to Roles from CLI
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# --
+# $Id: otrs.AddUser2Role.pl,v 1.5 2011-11-03 21:00:04 mb Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -9,23 +12,25 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 use strict;
 use warnings;
 
+# use ../ as lib location
 use File::Basename;
 use FindBin qw($RealBin);
 use lib dirname($RealBin);
-use lib dirname($RealBin) . '/Kernel/cpan-lib';
-use lib dirname($RealBin) . '/Custom';
+
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.5 $) [1];
 
 use Getopt::Std;
 use Kernel::Config;
@@ -38,6 +43,16 @@ use Kernel::System::Group;
 use Kernel::System::Main;
 use Kernel::System::User;
 
+# get options
+my %Opts;
+getopt( 'ur', \%Opts );
+if ( !$Opts{r} || !$Opts{u} ) {
+    print "$0 <Revision $VERSION> - assign Users to Roles\n";
+    print "Copyright (C) 2001-2011 OTRS AG, http://otrs.org/\n";
+    print "usage: $FindBin::Script -u <USER> -r <ROLE> \n";
+    exit 1;
+}
+
 # create common objects
 my %CommonObject = ();
 $CommonObject{ConfigObject} = Kernel::Config->new(%CommonObject);
@@ -52,16 +67,6 @@ $CommonObject{TimeObject}  = Kernel::System::Time->new(%CommonObject);
 $CommonObject{GroupObject} = Kernel::System::Group->new(%CommonObject);
 $CommonObject{UserObject}  = Kernel::System::User->new(%CommonObject);
 
-# get options
-my %Opts;
-getopt( 'ur', \%Opts );
-if ( !$Opts{r} || !$Opts{u} ) {
-    print "$0 - assign Users to Roles\n";
-    print "Copyright (C) 2001-2017 OTRS AG, http://otrs.com/\n";
-    print "usage: $FindBin::Script -u <USER> -r <ROLE> \n";
-    exit 1;
-}
-
 # check user
 my $UserID = $CommonObject{UserObject}->UserLookup( UserLogin => $Opts{u} );
 if ( !$UserID ) {
