@@ -1,6 +1,9 @@
-#!/usr/bin/perl
+#!/usr/bin/perl -w
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# scripts/tools/charset-convert.pl - converts a text file from one to an other one charset
+# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# --
+# $Id: charset-convert.pl,v 1.9 2009-02-26 11:10:53 tr Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -9,15 +12,18 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.9 $) [1];
+
 use strict;
 use warnings;
 
@@ -29,8 +35,8 @@ getopt( 'sdf', \%Opts );
 
 # usage
 if ( $Opts{h} ) {
-    print "charset-convert.pl - convert a charset of a file\n";
-    print "Copyright (C) 2001-2017 OTRS AG, http://otrs.com/\n";
+    print "charset-convert.pl <Revision $VERSION> - convert a charset of a file\n";
+    print "Copyright (C) 2001-2009 OTRS AG, http://otrs.org/\n";
     print "usage: charset-convert.pl -s <SOURCE_CHARSET> -d <DEST_CHARSET> -f <FILE>\n";
     print "       charset-convert.pl -s <SOURCE_CHARSET> -d <DEST_CHARSET> < file\n";
     exit 1;
@@ -65,7 +71,7 @@ elsif ( !-f $Opts{f} ) {
 
 # read file
 else {
-    open my $IN, '<', $Opts{f} || die "Can't open $Opts{f}: $!\n";    ## no critic
+    open my $IN, '<', $Opts{f} or die "Can't open $Opts{f}: $!\n";
     $In = do { local $/; <$IN> };
     close $IN;
 }
@@ -80,7 +86,7 @@ if (@STD) {
 
 # write
 else {
-    open my $Out, '>', $Opts{f} || die "Can't write $Opts{f}: $!\n";    ## no critic
+    open my $Out, '>', $Opts{f} || die "Can't write $Opts{f}: $!\n";
     print $Out $In;
     close $Out;
 }
